@@ -26,15 +26,15 @@ out2 <- lm_boot2est_i(dat, outputs = outputs)
 out2_db <- do_boot(fit = outputs, R = 5, seed = 81674958)
 
 test_that("lm2boot_out", {
-    expect_identical(
+    expect_equal(
         unname(out[[2]]$est$est[c(4, 1:3)]),
         unname(coef(out_chk))
       )
-    expect_identical(
+    expect_equal(
         unname(out2$est$est[c(4, 1:3)]),
         unname(coef(lm_m1))
       )
-    expect_identical(
+    expect_equal(
         out2_db,
         out
       )
